# MetroDB
A wrapper around the sqlite3 database for easy database development

The overall goal is to write less SQL and more Python.

## Installation
[![PyPI version](https://badge.fury.io/py/metro_db.svg)](https://badge.fury.io/py/metro_db)

    sudo pip3 install metro_db

## Documentation
[![readthedocs badget](https://readthedocs.org/projects/metro_db/badge/?version=latest)](http://metro_db.readthedocs.org/)

[`http://metro_db.readthedocs.org/`](http://metro_db.readthedocs.org/)

## Continuous Integration
[![Build Status](https://app.travis-ci.com/DLu/metro_db.svg?branch=main)](https://app.travis-ci.com/DLu/metro_db)
